@@ -18,7 +18,6 @@
 #include <KPluginMetaData>
 #include <KWindowSystem>
 #include <iostream>
-#include <kworkspace.h>
 
 #include "../core/kcmmetadatahelpers.h"
 #include "SettingsBase.h"
@@ -43,15 +42,9 @@ int main(int argc, char *argv[])
     // which is before KAboutData::setApplicationData
     QCoreApplication::setApplicationName(binaryName);
 
-    // This has to be before the QApplication is created.
-    KWorkSpace::detectPlatform(argc, argv);
-
     QApplication application(argc, argv);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    application.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-#endif
     // The ki18n application domain must be set before we make any i18n() calls.
-    KLocalizedString::setApplicationDomain("systemsettings");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("systemsettings"));
 
     KAboutData aboutData;
 
@@ -85,6 +78,7 @@ int main(int argc, char *argv[])
     }
 
     aboutData.addAuthor(i18n("Ben Cooksley"), i18n("Maintainer"), QStringLiteral("bcooksley@kde.org"));
+    aboutData.addAuthor(i18n("Marco Martin"), i18n("Author"), QStringLiteral("mart@kde.org"));
     aboutData.addAuthor(i18n("Mathias Soeken"), i18n("Developer"), QStringLiteral("msoeken@informatik.uni-bremen.de"));
     aboutData.addAuthor(i18n("Will Stephenson"), i18n("Internal module representation, internal module model"), QStringLiteral("wstephenson@kde.org"));
 
@@ -121,8 +115,8 @@ int main(int argc, char *argv[])
         for (const auto &metaData : modules) {
             QString entry(QStringLiteral("%1 - %2"));
 
-            entry = entry.arg(metaData.pluginId().leftJustified(maxLen, QLatin1Char(' ')))
-                        .arg(!metaData.description().isEmpty() ? metaData.description() : i18n("No description available"));
+            entry = entry.arg(metaData.pluginId().leftJustified(maxLen, QLatin1Char(' ')),
+                              !metaData.description().isEmpty() ? metaData.description() : i18n("No description available"));
 
             std::cout << entry.toLocal8Bit().data() << std::endl;
         }
@@ -150,11 +144,9 @@ int main(int argc, char *argv[])
 
     KCrash::initialize();
 
-    SettingsBase *mainWindow = new SettingsBase(mode);
-
-    QObject::connect(&service, &KDBusService::activateRequested, mainWindow, [mainWindow](const QStringList &arguments, const QString &workingDirectory) {
-        Q_UNUSED(workingDirectory);
+    auto mainWindow = new SettingsBase(mode, startupModule, args);
 
+    QObject::connect(&service, &KDBusService::activateRequested, mainWindow, [mainWindow](const QStringList &arguments) {
         // We can't use startupModule and args from above since they come from the existing instance, so we need to parse arguments.
         // We don't need to do the error checking again though.
         QCommandLineParser parser;
@@ -180,10 +172,5 @@ int main(int argc, char *argv[])
         KWindowSystem::activateWindow(mainWindow->windowHandle());
     });
 
-    if (!startupModule.isEmpty()) {
-        mainWindow->setStartupModule(startupModule);
-        mainWindow->setStartupModuleArgs(args);
-    }
-
     return application.exec();
 }
